#
# spec file for package deadbeef
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%bcond_with restricted

Name:           deadbeef
Version:        0.5.6
Release:        9.2
Summary:        GTK2 audio player
Group:          Productivity/Multimedia/Sound/Players
License:        GPL
Url:            http://deadbeef.sourceforge.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %name-%version.tar.bz2
Patch1:         deadbeef-fix_ubuntu_unity_desktop.patch
BuildRequires:  alsa-devel
%if 0%{?suse_version} >= 1210
Buildrequires:  gtk3-devel
%else
BuildRequires:  gtk2-devel
%endif
BuildRequires:  libcurl-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libvorbis-devel
BuildRequires:  flac-devel
BuildRequires:  libcddb-devel
BuildRequires:  libcdio-devel
BuildRequires:  libsndfile-devel
BuildRequires:  wavpack-devel
BuildRequires:  dbus-1-devel
BuildRequires:  gcc-c++
BuildRequires:  libnotify-devel
BuildRequires:  libpulse-devel
BuildRequires:  pkg-config
BuildRequires:  xorg-x11-libs
BuildRequires:  imlib2-devel
BuildRequires:  intltool
BuildRequires:  libjpeg-devel
BuildRequires:  libzip-devel
BuildRequires:  update-desktop-files
BuildRequires:  yasm
%if 0%{?sles_version}
BuildRequires:	xorg-x11-libxcb-devel
%endif

%if %{with restricted}
BuildRequires:  libfaad-devel
BuildRequires:  libffmpeg_oldabi-devel
BuildRequires:   libmad-devel
%endif

%description
DeaDBeeF is an audio player for GNU/Linux and other UNIX-like systems.
It is written in C with some plugins in C++. It has minimal dependencies,
a native GTK2 GUI, cuesheet support, support for MP3, Ogg, FLAC, and APE,
chiptune formats with subtunes, song-length databases, and more.
It is very fast and lightweight, and extensible using plugins
(DSP, GUI, output, input, etc.). The GUI looks similar to Foobar2000.

%if %{with restricted}

%package 	restricted-plugins
License:        GPL+ or Artistic
Summary:        Restricted plugins Support for %{name}
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}

%description restricted-plugins
XMMS2 is an audio framework, but it is not a general multimedia player - it
will not play videos. It has a modular framework and plugin architecture for
audio processing, visualisation and output, but this framework has not been
designed to support video. Also the client-server design of XMMS2 (and the
daemon being independent of any graphics output) practically prevents direct
video output being implemented. It has support for a wide range of audio
formats, which is expandable via plugins. It includes a basic CLI interface
to the XMMS2 framework, but most users will want to install a graphical XMMS2
client (such as gxmms2 or esperanza).
%endif

%package devel
License:        GPLv2
Group:          Development/Libraries/C and C++
Summary:        Devel files for %name
Requires:       pkg-config
Requires:       %name

%description devel
This package provides headers to develop deadbeef plugins

%prep
%setup -q
%patch1 -p1

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
CFGOPT="--enable-static=no"
%if 0%{?suse_version} >= 1210
CFGOPT="$CFGOPT --enable-gtk3 --disable-gtk2"
%endif
%if %{with restricted}
CFGOPT="$CFGOPT --enable-ffmpeg"
%endif
%configure $CFGOPT
%__make %{?jobs:-j%{jobs}}

%install
%makeinstall
%suse_update_desktop_file %name
%__rm %buildroot/%_libdir/deadbeef/*.la
%find_lang %name

%clean
%__rm -rf $RPM_BUILD_ROOT

%if 0%{?suse_version} >= 1140

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files -f %name.lang
%defattr(-,root,root)
%_bindir/%name
%dir %_libdir/%name
%_libdir/%name/adplug.so*
%_libdir/%name/alsa.so*
%_libdir/%name/artwork.so*
%_libdir/%name/cdda.so*
%_libdir/%name/ffap.so*
%_libdir/%name/flac.so*
%_libdir/%name/gme.so*
%_libdir/%name/hotkeys.so*
%_libdir/%name/lastfm.so*
%_libdir/%name/notify.so*
%_libdir/%name/nullout.so*
%_libdir/%name/oss.so*
%_libdir/%name/pulse.so*
%_libdir/%name/sid.so*
%_libdir/%name/sndfile.so*
%_libdir/%name/supereq.so*
%_libdir/%name/vfs_curl.so*
%_libdir/%name/vorbis.so*
%_libdir/%name/vtx.so*
%_libdir/%name/wavpack.so*
%_libdir/%name/dca.so*
%_libdir/%name/mms.so*
%_libdir/%name/musepack.so*
%_libdir/%name/shellexec.so*
%_libdir/%name/tta.so*
%_libdir/%name/wildmidi.so*
%_libdir/%name/converter.so*
%_libdir/%name/dsp_libsrc.so*
%_libdir/%name/m3u.so*
%_libdir/%name/vfs_zip.so*
%_libdir/%name/ddb_ao.so*
%_libdir/%name/ddb_dumb.so*
%_libdir/%name/ddb_mono2stereo.so*
%_libdir/%name/ddb_shn.so*
%_libdir/%name/alac.so*
%if 0%{?suse_version} >= 1210
%_libdir/%name/converter_gtk3.so*
%_libdir/%name/ddb_gui_GTK3.so*
%_libdir/%name/shellexecui_gtk3.so*
%else
%_libdir/%name/converter_gtk2.so*
%_libdir/%name/ddb_gui_GTK2.so*
%_libdir/%name/shellexecui_gtk2.so*
%endif
%_datadir/%name
%_datadir/applications/deadbeef.desktop
%_datadir/icons/hicolor/*x*/apps/%name.png
%_datadir/icons/hicolor/scalable/apps/%name.svg
%_datadir/doc/%name
%dir %_libdir/%name/convpresets
%_libdir/%name/convpresets/*.txt

%if %{with restricted}

%files restricted-plugins
%defattr(-,root,root,-)
%_libdir/deadbeef/aac.so*
%_libdir/deadbeef/ffmpeg.so*
%_libdir/deadbeef/mpgmad.so*
%endif

%files devel
%defattr(-,root,root)
%_includedir/%name

%changelog
* Wed Dec 19 2012 andrea@opensuse.org
- new upsream version 0.5.6
  - wavpack: fixed reload_metadata not clearing old data
  - sndfile: fixed big/little endian byte swap buffer overrun
  - gme: fixed loopcount bugs
  - alsa: fixed race condition bug leading to freezes
  - alac: added new ALAC plugin with proper gapless playback support and other goods
  - aac: lots of bugfixes and improvements, as usual, including half/double
    duration bugfix, and custom metadata fields support, and audiobook chapters
  - cue and m3u parsers can now skip utf8 BOM
  - automatically fill new/edited column title from the selected column type
  - removed the frame widget around playlist to make scroll bar more accessible
    in maximized windows
  - restored old GDK drawing in GTK2 plugin, because cairo produces weird results on
    older GTK2 versions -- that means, tabs and playlist now look correct again
    with gtk2.20 and below
  - gtk3 compiling is now enabled by default, if gtk3 sdk is installed
  - --enable/disable-gtkui configure option is removed, now there are only --enable/disable-gtk2
    and --enable/disable-gtk3
  - added Menu key support
  - always auto-name playlist by folder name when empty, even if the playlist title is non-default
  - insert/delete key support in track properties (Ruslan Khusnullin)
  - fixed Enter and Esc keys in track properties
  - fixed playlist column auto-resizing in maximized window
  - added user-agent configuration for last.fm, vfs_curl, etc
  - added cp936 charset detection support. it breaks cp1251 detection, so it's done as an option
  - - look in the preferences (Joey Zheng)
  - show blank instead of "?" when a metadata field is absent
  - fixed local album cover files search order, it's alphabetical now
  - alsa: added a hack/work-around to prevent releasing sound device when a user switches between tracks
  - m3u: improved handling of relative file pathes
  - converter: fixed handling "/" in filenames; fixed tag-writing to files which have special characters
  - fixed resuming last session in shuffle albums mode
  - fixed several libmms freeze/hang/crash bugs
  - vorbis: update waveformat dynamically, so now it's possible to listen the radios which
    switch between mono and stereo dynamically
  - mp3: fixed samplerate shown in the track properties
  - added work-around for unsupported channel masks to wavpack and sndfile plugins
  - fixed notification cover-art loading for tracks with empty album
* Wed Sep 26 2012 jzheng@suse.com
- update to git commit 8f3b1661fd1372508b35de39ca1cc405f1111c0e
- remove patch files as upstream accepts them
- update deadbeef-fix_ubuntu_unity_desktop.patch
- update spec to include alac
* Sat Sep  8 2012 jzheng@suse.com
- update deadbeef_Fix_CDTEXT.patch to prepare for upstream
* Thu Aug 30 2012 jzheng@suse.com
- update to 0.5.5
- remove deadbeef-0.5.0-fix-return-values.patch and
  deadbeef-0.5.0-fix-strcmp.patch as no need any more.
- refresh deadbeef_FixGB.patch and fix_ubuntu_unity_desktop.patch
  based on now version.
- add deadbeef_gtk_combo_box_entry_new_text.patch
- add deadbeef_Fix_CDTEXT.patch
- add enable-gtk3 option to enable gtk3 interface for openSUSE 12.x
- add new plugin files to file list
* Mon Jan 30 2012 jzheng@suse.com
- let version higher than the one in pacman to avoid some update
  issues.
* Sun Jan 29 2012 i@marguerite.su
- Fix Ubuntu Unity Oriented Desktopfile Warnings. SuSE doesn't need that.
* Sun Jan 29 2012 jzheng@suse.com
- Add hack to support cp936 (GBK, GB18030)
* Sat Jun  4 2011 andrea@opensuse.org
- New upstream version 0.5.1
* Mon May 16 2011 andrea@opensuse.org
- New upstream version 0.5.0
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un and %%icon_theme_cache_post/un
* Thu Dec  2 2010 gber@opensuse.org
- added deadbeef-0.4.4-fix-undefined-assignments.patch and
  deadbeef-0.4.4-fix-return-value.patch to fix compile warnings
* Wed Dec  1 2010 andrea@opensuse.org
- new upstream version 0.4.4
  - fixed crash in OSS plugin
  - fixed random crashes caused by upgrading to libcurl-7.21.2
  - fixed metadata editing in non-english locales
  - fixed switching playlists using hotkeys with caps/num/xcb
  modifiers
  - made preferences window tabs scrollable
  - fixed dts plugin description
  - fixed 'n' hotkey with numlock
  - improved support for icy (shoutcast) protocol
  - fixed ctrl+j (jump to current track) to work correctly with
  multiple playlists
  - fixed cursor/scroll follows playback to work correctly with
  multiple playlists
  - session resume does not seek anymore after skipping failed track
  - fixed seekbar flickering
  - bundled libmms library to fix freezes after updating to 0.6
  - blank cue tracks (without titles) are not skipped anymore
  - fixed trailing whitespace handling in cuesheets
  - "middle mouse button to delete playlist" is now default behavior
  - fixed few issues with auto-saving playlist configuration
  - fixed playlist redraw after cddb queries
* Fri Jun  4 2010 andrea@opensuse.org
- new upstream version 0.4.1 - bug fix release
* Mon May 24 2010 andrea@opensuse.org
- added deadbeef-0.4.0-fix-critical-warning.patch to make
  brp-checks happy
* Sun May 23 2010 andrea@opensuse.org
- New package
